const low = require('lowdb')
const FileSync = require('lowdb/adapters/FileSync')
const adapter = new FileSync('db.json');
const db = low(adapter);
const badges = require('./baseDb.js').library;
const users = require('./baseDb.js').users;
const pitches = require('./baseDb.js').pitches;
const archetypes = require('./baseDb.js').archetypes;

const startingBadges = users[0].badges;

db.defaults({ heartbeat: 1, badges, users, pitches, archetypes })
  .write();

const dbLayer = {};

dbLayer.heartbeat = () => db
  .get('heartbeat')
  .value();

dbLayer.saveBadge = badge => db
  .get('badges')
  .push(badge)
  .write();

dbLayer.getBadges = () => db
  .get('badges')
  .value();

dbLayer.getBadgeByNameAndVersion = (name, version) => db
  .get('badges')
  .find({ name, version })
  .value();

dbLayer.getUsers = () => db
  .get('users')
  .value();

dbLayer.getUserByToken = (tokenAuth) => db
  .get('users')
  .find({ tokenAuth })
  .value();

dbLayer.getUserByName = (name) => db
  .get('users')
  .find({ name })
  .value();

dbLayer.saveUser = (name, tokenAuth, pic) => db
  .get('users')
  .push({name, tokenAuth, pic, badges: (startingBadges  || [])})
  .write();

  dbLayer.getAdmins = () => db
  .get('users')
  .filter('admin')
  .map('tokenAuth')
  .value();

dbLayer.savePitch = (username, badgeName, oldLevel, pitchedLevel, pitchMessage, holders, timestamp ) => db
  .get('pitches')
  .push({ username, badgeName, oldLevel, pitchedLevel, pitchMessage, holders, timestamp })
  .write();

dbLayer.getPitches = () => db
  .get('pitches')
  .value();

dbLayer.getPitchByPicherAndBadge = (username, badgeName) => db
  .get('pitches')
  .find({ username, badgeName })
  .value();

dbLayer.updatePitch = (pitcherName, badgeName, username, newStatus, newMessage) => db
  .get('pitches')
  .find({ username: pitcherName, badgeName })
  .get('holders')
  .find({name: username})
  .assign({pitchStatus: newStatus})
  .assign({message: newMessage})
  .write();

dbLayer.getArchetypes = () => db
  .get('archetypes')
  .value();

module.exports = dbLayer;  
